% NOTE: You need Matlab version R2016b or newer to run the OpenLab simulator

clear variables;
clc;
close all;

% Add to the matlab path the folder where this file is located and all the
% subfolders
addpath(genpath(pwd));

IdentityServerURL = 'https://live.openlab.app/';

[username, api_key, license_guid] = GetLoginData();

% Select the configuration you want to run simulations on
ConfigurationName = 'Your configuration name';

% Choose a name on your simulation and set some initial parameters
SimulationName = 'Influx (Matlab)';
InitialBitDepth = 2500; % [m]
InitialTopOfStringPosition = 20; 

% Influx/loss configuration
UseReservoirModel = true; % false: no influx and loss, true: influx and lsos
ManualReservoirMode = false; % true: manual influx/loss, false: influx based on geo-thermal (only if UseReservoirModel is true)
ManualInfluxLossMassRate = 0; % [kg/s] (positive for influx, negative for loss)
ManualInfluxLossTotalMass = 0; % [kg]
ManualInfluxLossMD = InitialBitDepth; %2500; % [m]
ReservoirKickOffTime = 15; % [s]

% Create simulation object
Sim = OpenLabClient(IdentityServerURL,username,api_key,license_guid,ConfigurationName,SimulationName,InitialBitDepth,InitialTopOfStringPosition,...
    UseReservoirModel,ManualReservoirMode,ManualInfluxLossMassRate,ManualInfluxLossTotalMass,ManualInfluxLossMD,ReservoirKickOffTime);

if Sim.IsOK
    try
        for timeStep = 1 : 30000
            tStartStep = tic;
            
            % Set setpoints to the simulator
            Sim.TopOfStringVelocity = 0;
            Sim.SurfaceRPM = 0;
            Sim.ChokePumpFlowRateIn = 0;
            Sim.ChokeOpening = 1;
            Sim.BopChokeOpening = 1;
            
            if timeStep < 60                        
                Sim.FlowRateIn = 0/60000;
            else
                Sim.FlowRateIn = 2000/60000;
            end
    
            Sim.Step();
            
            if ~Sim.IsOK
                break;
            end      
                  
            display(['Total step duration: ' num2str(toc(tStartStep))]);
        end
        
        % Stop simulation
        Sim.Stop;
        
    catch exception
        % Stop simulation
        Sim.Stop;
        
        rethrow(exception);
    end
    
end
