% NOTE: You need Matlab version R2016b or newer to run the OpenLab simulator

clear variables;
clc;
close all;

% Add to the matlab path the folder where this file is located and all the
% subfolders
addpath(genpath(pwd));

IdentityServerURL = 'https://live.openlab.app/';

[username, api_key, license_guid] = GetLoginData();

% Select the configuration you want to run simulations on
ConfigurationName = 'Your configuration name';

% Choose a name on your simulation and set some initial parameters
SimulationName = 'Manual influx (Matlab)';
InitialBitDepth = 2400; % [m]
InitialTopOfStringPosition = 20;

% Influx/loss configuration
UseReservoirModel = true; % false: no influx and loss, true: influx and lsos
ManualReservoirMode = true; % true: manual influx/loss, false: influx based on geo-thermal (only if UseReservoirModel is true)
ManualInfluxLossMassRate = 0.5; % [kg/s] (positive for influx, negative for loss)
ManualInfluxLossTotalMass = 40; % [kg]
ManualInfluxLossMD = InitialBitDepth; %2500; % [m]
ReservoirKickOffTime = 15; % [s]

% Create simulation object
Sim = OpenLabClient(IdentityServerURL,username,api_key,license_guid,ConfigurationName,SimulationName,InitialBitDepth,InitialTopOfStringPosition,...
    UseReservoirModel,ManualReservoirMode,ManualInfluxLossMassRate,ManualInfluxLossTotalMass,ManualInfluxLossMD,ReservoirKickOffTime);

if Sim.IsOK
    try
        for timeStep = 1 : 300
            tStartStep = tic;
            
            % Set setpoints to the simulator
            Sim.TopOfStringVelocity = 0;
            Sim.SurfaceRPM = 0;
            Sim.ChokePumpFlowRateIn = 0;
            Sim.ChokeOpening = 1;
            Sim.BopChokeOpening = 1;
            Sim.FlowRateIn = 2000/60000;
            
            Sim.Step();
            
            if ~Sim.IsOK
                break;
            end
            
            %             GasVolumeFractionLog(timeStep,:) = [Sim.GasVolumeFraction(0) Sim.GasVolumeFraction(1500) Sim.GasVolumeFraction(2000) Sim.GasVolumeFraction(2200) ...
            %                 Sim.GasVolumeFraction(2300) Sim.GasVolumeFraction(2350) Sim.GasVolumeFraction(2400)  Sim.GasVolumeFraction(2450) Sim.GasVolumeFraction(2500)];
            
            display(['Total step duration: ' num2str(toc(tStartStep))]);
        end
        
        % Stop Simulation process
        Sim.Stop;        
        %         figure; plot(GasVolumeFractionLog*100); title('GasVolumeFraction [%]'); grid;
        %         legend({'0m' '1000m' '1500m' '2200m' '2300m' '2350m' '2400m' '2450m' '2500m' });
        
    catch exception
        % Stop simulation
        Sim.Stop;
        
        rethrow(exception);
    end
    
end
